==> kubernetes-client-4.10.3-sources.jar: io/fabric8/kubernetes/client/dsl/internal/apps/v1/ControllerRevisionOperationsImpl.java <==

                                          
      

package io.fabric8.kubernetes.client.dsl.internal.apps.v1;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.kubernetes.client.dsl.Resource;
import io.fabric8.kubernetes.client.dsl.base.HasMetadataOperation;
import io.fabric8.kubernetes.client.dsl.NonNamespaceOperation;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;
import io.fabric8.kubernetes.client.dsl.base.OperationContext;

import okhttp3.OkHttpClient;

import io.fabric8.kubernetes.api.model.apps.DoneableControllerRevision;
import io.fabric8.kubernetes.api.model.apps.ControllerRevision;
import io.fabric8.kubernetes.api.model.apps.ControllerRevisionList;
import io.fabric8.kubernetes.api.model.apps.DoneableControllerRevision;

import java.util.Map;
import java.util.TreeMap;


public class ControllerRevisionOperationsImpl extends HasMetadataOperation<ControllerRevision, ControllerRevisionList, DoneableControllerRevision, Resource<ControllerRevision, DoneableControllerRevision>> {

  public ControllerRevisionOperationsImpl(OkHttpClient client, Config config) {
    this(client, config, null);
  }

  public ControllerRevisionOperationsImpl(OkHttpClient client, Config config, String namespace) {
    this(new OperationContext().withOkhttpClient(client).withConfig(config).withNamespace(namespace).withPropagationPolicy(DEFAULT_PROPAGATION_POLICY));
  }

  public ControllerRevisionOperationsImpl(OperationContext context) {
    super(context.withApiGroupName("apps")
    .withApiGroupVersion("v1")
    .withPlural("controllerrevisions"));
    this.type = ControllerRevision.class;
    this.listType = ControllerRevisionList.class;
    this.doneableType = DoneableControllerRevision.class;
  }

  public ControllerRevisionOperationsImpl newInstance(OperationContext context) {
    return new ControllerRevisionOperationsImpl(context);
  }

  @Override
  public boolean isResourceNamespaced() {
    return true;
  }
}

==> kubernetes-client-5.0.0-sources.jar: io/fabric8/kubernetes/client/dsl/internal/apps/v1/ControllerRevisionOperationsImpl.java <==

                                          
      

package io.fabric8.kubernetes.client.dsl.internal.apps.v1;

import io.fabric8.kubernetes.api.builder.Visitor;
import io.fabric8.kubernetes.client.Config;
import io.fabric8.kubernetes.client.dsl.Resource;
import io.fabric8.kubernetes.client.dsl.base.HasMetadataOperation;
import io.fabric8.kubernetes.client.dsl.NonNamespaceOperation;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;
import io.fabric8.kubernetes.client.dsl.base.OperationContext;

import okhttp3.OkHttpClient;

import io.fabric8.kubernetes.api.model.apps.ControllerRevision;
import io.fabric8.kubernetes.api.model.apps.ControllerRevisionBuilder;
import io.fabric8.kubernetes.api.model.apps.ControllerRevisionList;

import java.util.Map;
import java.util.TreeMap;


public class ControllerRevisionOperationsImpl extends HasMetadataOperation<ControllerRevision, ControllerRevisionList, Resource<ControllerRevision>> {

  public ControllerRevisionOperationsImpl(OkHttpClient client, Config config) {
    this(client, config, null);
  }

  public ControllerRevisionOperationsImpl(OkHttpClient client, Config config, String namespace) {
    this(new OperationContext().withOkhttpClient(client).withConfig(config).withNamespace(namespace).withPropagationPolicy(DEFAULT_PROPAGATION_POLICY));
  }

  public ControllerRevisionOperationsImpl(OperationContext context) {
    super(context.withApiGroupName("apps")
    .withApiGroupVersion("v1")
    .withPlural("controllerrevisions"));
    this.type = ControllerRevision.class;
    this.listType = ControllerRevisionList.class;
  }

  public ControllerRevisionOperationsImpl newInstance(OperationContext context) {
    return new ControllerRevisionOperationsImpl(context);
  }

  @Override
  public ControllerRevision edit(Visitor... visitors) {
    return patch(new ControllerRevisionBuilder(getMandatory()).accept(visitors).build());
  }

  @Override
  public boolean isResourceNamespaced() {
    return true;
  }
}
